pub struct AAVarTracker { /* private fields */ }Implementations
Sourceimpl AAVarTracker
impl AAVarTracker
pub fn new() -> Self
pub fn new_at(id: u64) -> Self
pub fn next(&self) -> u64
pub fn peek(&self) -> u64
Sourcepub fn make_clone(&self) -> Self
pub fn make_clone(&self) -> Self
Clone this ID tracker. After this is done, only one of the ID trackers may be used otherwise duplicate IDs will be generated. It is up to the caller of this method to make sure that no mutable references are handed out to one of the clonse