pub struct NameID(pub u64, pub Path);Expand description
Anything named will get assigned a unique name ID during AST lowering in order to avoid caring about scopes once HIR has been generated. This is the type of those IDs
The associated string is only used for formatting when printing. The hash and eq methods do not use it
Tuple Fields
0: u641: PathTrait Implementations
Sourceimpl<'de> Deserialize<'de> for NameID
impl<'de> Deserialize<'de> for NameID
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for NameID
impl Ord for NameID
Sourceimpl PartialOrd for NameID
impl PartialOrd for NameID
impl Eq for NameID